
module BoardsWatchers
  module Patches
    module StickyPriorityMessagePatch
      def self.included(base) # :nodoc:
        base.send(:include, InstanceMethods)
        base.class_eval do
          unloadable

          attr_protected :sticky_priority
          #alias_method_chain :issues, :parent_sort
          #alias_method_chain :issue_ids, :parent_sort if Query.method_defined?(:issue_ids)
        end
      end

      module InstanceMethods
        def sticky_priority=(arg)
          if sticky?
            new_priority=arg.to_i
            new_priority=1 if new_priority == 0
            write_attribute :sticky_priority, new_priority
          else
            write_attribute :sticky_priority, 0
          end
        end

        def sticky_priority
          sp=read_attribute(:sticky_priority) || 0
          sp=1 if sp==0 && sticky?
          sp
        end
      end
    end

    module ApplicationHelperPatch
      def self.included(base) # :nodoc:
        base.send(:include, InstanceMethods)
        base.class_eval do
          unloadable

          alias_method_chain :render_page_hierarchy, :watchers
        end
      end

      module InstanceMethods
        def render_page_hierarchy_with_watchers(pages, node=nil, options={})
          content = ''
          if pages[node]
            content << "<ul class=\"pages-hierarchy\">\n"
            pages[node].each do |page|
              content << "<li>"
              content << link_to(h(page.pretty_title), {:controller => 'wiki', :action => 'show', :project_id => page.project, :id => page.title},
                                 :title => (options[:timestamp] && page.updated_on ? l(:label_updated_time, distance_of_time_in_words(Time.now, page.updated_on)) : nil))
              if authorize_for("boards_watchers", "manage_wiki")
                content << link_to("(#{page.watcher_users.size})", {:controller => 'boards_watchers', :action => 'manage_wiki', :project_id => @project, :id => page.title}, :class => (page.watcher_users.size > 0 ? 'icon icon-fav' : 'icon icon-fav-off'))
              end
              content << "\n" + render_page_hierarchy(pages, page.id, options) if pages[page.id]
              content << "</li>\n"
            end
            content << "</ul>\n"
          end
          content.html_safe
        end
      end

    end

  end
end
